% BERUB = BERCODING(EbNo, 'block', DECISION, N, K, DMIN) returns an upper
%   bound of the BER of (N, K) linear binary block codes with coherent BPSK
%   or QPSK modulation. 
%   DMIN -- minimum distance of the code, bounded by DMIN <= N - K + 1.

clear all
EbNo=0:1:15; % [dB]

% PSK %
% Hamming (31/26) %
n_h=15 ; 
k_h=11; 
rc=k_h/n_h ;   % Code rate
pe_psk=berawgn(EbNo,'psk',2,'diff');      % Theoretical Uncoded Pe for BPSK
EbNodBcoded=EbNo+ 10*log10(rc)   ;        % EbNo coded
ph=berawgn(EbNodBcoded, 'psk', 4, 'diff');% Pe for EbNo coded
ber_hpsk = ph-ph.*(1-ph).^(n_h-1);        % Coded BER 

% Reed Solomon %
m=4 ;  % Symbols (4-PSK)
k_rs=13; 
n_rs=(2^m)-1; 
ber_rs=bercoding(EbNo, 'RS', 'hard', n_rs, k_rs) ;
pe_4psk=berawgn(EbNo,'psk',4,'diff');      % Theoretical Uncoded Pe for 4PSK

% FSK %
% Hamming (57/63) %
pe_fsk=berawgn(EbNo,'fsk',2,'coherent');     % Theoretical Uncoded Pe for BFSK
ph2=berawgn(EbNodBcoded, 'fsk', 4, 'coherent');  % Pe for EbNo coded
ber_hfsk = ph2-ph2.*(1-ph2).^(n_h-1);        % Coded BER 

% Hamming Binary PSK and FSK%
n_h2=3 ; 
k_h2=1; 
rc2=k_h2/n_h2 ;   % Code rate
EbNodBcoded2=EbNo+ 10*log10(rc2)   ;          % EbNo coded
ph3=berawgn(EbNodBcoded2, 'psk', 2, 'diff');  % Pe for EbNo coded
ber_hpsk2 = ph3-ph3.*(1-ph3).^(n_h2-1);      % Coded BER 
ph4=berawgn(EbNodBcoded2, 'fsk', 2, 'coherent');  % Pe for EbNo coded
ber_hfsk3 = ph4-ph4.*(1-ph4).^(n_h2-1);      % Coded BER 

   
% Plot BER vs EbNo 4-ary%
figure
semilogy(EbNo,pe_fsk,'y');
hold on;
semilogy(EbNo,ber_hfsk,'c');
hold on;
semilogy(EbNo,pe_psk,'b');
hold on;
semilogy(EbNo,ber_hpsk,'m');
hold on;
semilogy(EbNo,ber_rs,'g');
hold on;
legend('Uncoded BFSK','11/15 Hamming Coded 4-FSK', 'Uncoded BPSK',...
      '11/15 Hamming Coded 4-PSK','13/15 4-PSK Reed Solomon Coded');  
xlabel('Eb/No [dB]');
ylabel('Bit Error Rate (BER)');
grid on
axis([0 15 1e-6 1e-1]) ;
hold on;


% Plot BER vs EbNo Binary%
figure
semilogy(EbNo,pe_fsk,'m');
hold on;
semilogy(EbNo,ber_hfsk3,'m--');
hold on;
semilogy(EbNo,pe_psk,'b');
hold on;
semilogy(EbNo,ber_hpsk2,'b--');
hold on;
legend('Uncoded BFSK','1/3 Hamming Coded BFSK', 'Uncoded BPSK',...
      '1/3 Hamming Coded BPSK');  
xlabel('Eb/No [dB]');
ylabel('Bit Error Rate (BER)');
grid on
axis([0 15 1e-6 1e-1]) ;
hold on;


 