% Present script estimates Error probability for BFSK Modulation 
% by means of iterations based on Monte Carlo simulation method, Eb/No is a
% vector called from link_budget.m template. Then, it makes a comparision
% between simulated and theoretical BER.

clear all
close all

link_budget

ebnodB_aux1=EbNo_96;          
ebnodB_aux2=EbNo_18;  

ebnodB1=ebnodB_aux1(1:25:length(ebnodB_aux1));   %Eb/No for 9600bps from Link budget template
ebnodB2=ebnodB_aux2(1:25:length(ebnodB_aux2));   %Eb/No for 1800bps from Link budget template
nbits1=10000;

ebno1=10.^(ebnodB1/10) ;
ebno2=10.^(ebnodB2/10) ;

h=waitbar(0,'SNR Iteration');
lebno=length(ebnodB1);

for j=1:lebno
    waitbar(j/lebno);
    sigma1=sqrt(1/(2*ebno1(j)));
    sigma2=sqrt(1/(2*ebno2(j)));
    nerrors1=0;
    nerrors2=0;
    for k=1:(nbits1+(lebno*10000))
        
        d1=round(rand(1));
        
        % Transmitter
        if d1==0
            xd1=1;
            xq1=0;
        else
            xd1=0;
            xq1=1;
        end
        
        % AWGN Noise
        nd1=sigma1*randn(1);
        nq1=sigma1*randn(1);
        
        nd2=sigma2*randn(1);
        nq2=sigma2*randn(1);
        
        % Receiver
        yd1=xd1+nd1;
        yq1=xq1+nq1;
        
        yd2=xd1+nd2;
        yq2=xq1+nq2;
        
        % Detection
        if yd1>yq1
            dest1=0;
        else
            dest1=1;
        end
        if(dest1 ~=d1)
            nerrors1=nerrors1+1;
        end
             
        %1800
        if yd2>yq2
            dest2=0;
        else
            dest2=1;
        end
        if(dest2 ~=d1)
            nerrors2=nerrors2+1;      % Errors counter 
        end
        
    end
    
    errors1(j)=nerrors1;
    errors2(j)=nerrors2;
end
close(h)

% Calculate BER by counting generated errors from iterations.
ber_s1=errors1/(nbits1+(lebno*10000));
ber_s2=errors2/(nbits1+(lebno*10000));

% Calculate BER by using theoretical form.
ber_t1=0.5*erfc(sqrt(0.5*ebno1));
ber_t2=0.5*erfc(sqrt(0.5*ebno2));

% Plot BER 
figure
semilogy(ebnodB1,ber_t1,'b')
hold on
semilogy(ebnodB1,ber_s1,'m+')
hold on
semilogy(ebnodB1,ber_t2,'b')
hold on
semilogy(ebnodB1,ber_s2,'m+')
hold on
axis([-10 20 0.00001 1])
xlabel('EbNo [dB]')
ylabel('Bit Error Probability')
legend('Theoretical', 'Simulation')


