% Present script estimates Error probability for BPSK Modulation 
% by means of iterations based on Monte Carlo simulation method, Eb/No is a
% vector called from link_budget.m template. Then, it makes a comparision
% between simulated and theoretical BER.

clear all
close all

link_budget

ebnodB_aux1=EbNo_96;          
ebnodB_aux2=EbNo_18;  
ebnodB1=ebnodB_aux1(1:25:length(ebnodB_aux1));   %Eb/No for 9600bps from Link budget template
ebnodB2=ebnodB_aux2(1:25:length(ebnodB_aux2));   %Eb/No for 1800bps from Link budget template
nbits1=100000;
ebno1=10.^(ebnodB1/10) ;
ebno2=10.^(ebnodB2/10) ;

h3=waitbar(0, 'Executing iterations');
lebno=length(ebnodB1);
for i=1:lebno
    waitbar(i/lebno)
    
    sigma1=sqrt(1/(2*ebno1(i)));     % Noise deviation
    sigma2=sqrt(1/(2*ebno2(i)));     % Noise deviation
    
    error_count1=0 ;
    error_count2=0 ;
    
    for j=1:(nbits1+(lebno*10000))
        
        % Transmitted signal
        bits1=round(rand(1));        
        s1=2*bits1-1;                %Transmitted signal
        
        % AWGN noise
        noise1=sigma1*randn(1);      
        noise2=sigma2*randn(1);      
        
        % Received signal
        ns1=s1+noise1;
        ns2=s1+noise2;
        
        % Detection for signal to 9600 bps
        if ns1>0
            dbits1=1;
        else
            dbits1=0;
        end
        if (dbits1 ~=bits1)
            error_count1=error_count1+1;
        end
       
         % Detection for signal to 1800 bps
        if ns2>0
            dbits2=1;
        else
            dbits2=0;
        end
        if (dbits2 ~=bits1)
            error_count2=error_count2+1;    % Errors counter 
        end
        
    end
    errors1(i)=error_count1;           
    errors2(i)=error_count2;
end
close(h3)

% Calculate BER by counting generated errors from iterations.
ber_s1=errors1/(nbits1+(lebno*10000));
ber_s2=errors2/(nbits1+(lebno*10000));

% Calculate BER by using theoretical form.
ber_t1=0.5*erfc(sqrt(10.^(ebnodB1/10)));
ber_t2=0.5*erfc(sqrt(10.^(ebnodB2/10)));

% Plot BER 
figure
semilogy(ebnodB1,ber_t1,'b')
hold on
semilogy(ebnodB1,ber_s1,'m+')
hold on
semilogy(ebnodB1,ber_t2,'b')
hold on
semilogy(ebnodB1,ber_s2,'m+')
hold on
axis([-10 20 0.00001 1])
xlabel('EbNo [dB]')
ylabel('Bit Error Probability')
legend('Theoretical', 'Simulation')



