% This script calculates effective noise temperature at Earth Station
% and On board receiver considering that
% System Temperature= Antenna temperature + Composite temperature
% Composite temperature= 
     % Line antenna to lna temperature...
     % + LNA temperature 
     % + Line from LNA to front end receiver temperature
     
B=25000 ;            % Bandwidth  [Hz]
k=1.38e-23 ;         % Boltzman's constant 
B_db=10*log10(B) ;   % RX (Noise) Bandwidth [dBHz]
Tsky_VHF=1000 ;      % Sky temperature for 145.9 MHz at elevation of 0 degrees [K]
Tsky_UHF=150 ;       % Sky temperature for 438.5 MHz at elevation of 0 degrees [K]
n=0.7  ;             % Antenna efficiency
To=290 ;             % Reference Temperature [k]

% Antenna Noise Temperature
Ta_es_VHF=Tsky_VHF*n+(To*(1-(1/3))*(1-n))+(Tsky_VHF*(1/3)*(1-n)) ;
Ta_es_UHF=Tsky_UHF*n+(To*(1-(1/3))*(1-n))+(Tsky_UHF*(1/3)*(1-n)) ;

% DOWNLINK (Rx at Earth Station)
Ts= 274.02 ;          % Surface Temperature [K]
To_es=(1.12*Ts)-50 ;    % Enviroment Temperature [k]

Ll1_VHF= 1.48 ;      % Loss line antenna-lna. Actual value.
Ll2_VHF=3.28 ;       % Loss line lna-front receiver. Actual value.

Ll1_UHF=1.9  ;       % Loss line antenna-lna. Actual value.
Ll2_UHF=5.08 ;       % Loss line lna-front receiver. Actual value.

NFlna_es=1.5 ;       % LNA Noise figure. Actual value.
Glna_es=15 ;         % LNA gain. Actual value.

%Composite temperature
Tcomp_es_VHF=To_es*(Ll1_VHF-1)+(To_es*(NFlna_es-1)/(1/Ll1_VHF))+(To_es*(Ll2_VHF-1)/((1/Ll1_VHF)*Glna_es)) ;
Tcomp_es_UHF=To_es*(Ll1_UHF-1)+(To_es*(NFlna_es-1)/(1/Ll1_UHF))+(To_es*(Ll2_UHF-1)/((1/Ll1_UHF)*Glna_es)) ;

%System Temperature=Antenna temperature+Composite temperature
Ts_dl_VHF=Ta_es_VHF+Tcomp_es_VHF
Ts_dl_UHF=Ta_es_UHF+Tcomp_es_UHF

% UPLINK (Rx at Satellite)
To_sat=To ;
Ta_sat=To ;         % Antena temperature On board
Ll_VHF=1.5 ;         % Loss line antenna-switch (2 connector+ 0.5dB cable)
Ll_UHF=3 ;           % Loss line antenna-switch (2 connector+ 1 dB cable)
Lsw=0.5 ;            % Switch loss
NFlna_sat=1.2 ;      % Noise figure, proposed value.
Glna_sat=15 ;        % LNA Gain, proposed value.

%Composite temperature
Tcomp_sat_VHF=To_sat*(Ll_VHF-1)+(To_sat*(Lsw-1)/(1/Ll_VHF))+(To*(NFlna_sat-1)/((1/Ll_VHF)*(1/Lsw))) ;
Tcomp_sat_UHF=To_sat*(Ll_UHF-1)+(To_sat*(Lsw-1)/(1/Ll_UHF))+(To*(NFlna_sat-1)/((1/Ll_UHF)*(1/Lsw))) ;

%System Temperature=Antenna temperature+Composite temperature                                                
Ts_up_VHF=Ta_sat+Tcomp_sat_VHF
Ts_up_UHF=Ta_sat+Tcomp_sat_UHF





