function U=pattern_dipole(theta,varargin)
% Returns the radiation intensity U of a dipole (not normalized)
%
% Possible inputs:
% theta-the theta direction of the intensity (radians)
% z axis-Use the z?axis in the nadir-direction? (true/false)
% length-length of dipole in number of wavelength (default:0.5)
%
% Usually the z?axis for a dipole antenna is oriented along its minima
% and theta=90 is at its maxima. The offset angle is referred to nadir
% such that an offset of 0 degree is at maxima. By setting z?axis=true
% theta is rotated such that theta=0 at pattern maxima. And theta can be
% set equal to the offset angle. Default behaviour is, false, the
% standard in antenna theory. If it is set to true then z?axis will will
% point in nadir such that when the ta~=0 then the pattern will actually
% depend upon another variable phi. This variable is not taken care off
% and the worst case is assumed.

% Handling optional arguments
optargs={false,false,0.5}; % default arguments
newvals=cellfun(@(x)~isempty(x),varargin) ; % get indice  to non?empty arguments
optargs(newvals)= varargin(newvals) ; % replace default values
[zaxis,db,length]=optargs {:} ; % store in variables

if(zaxis) % Use nadir as z?axis (the ta=0)
  theta=theta+90 ;
end

theta=theta*pi/180; % convert to rad

kl=2*pi*length ;

U=((cos((kl/2)*cos(theta))-cos((kl/2)))./sin(theta)).^ 2 ;

U(theta==0)=0 ; % Set U=0 for elements where theta=0 due to 0/0?expression which returns NaN

if (db)
  U=10*log10(U) 
end

end