% This is a script that plots the downloaded data per average day for
% different orbital heights and threshold elevation angles .
% clear all
% ============================ NOTES ======================================
% Code read three different files called fname_400, fname_600 and fname_800
% which contain information related to access time and elevation angle,
% each file correspond to a height, they were generated in Satellite Tool
% Kit Software and are read calling read_stk_elev function.
% Simulation in STK were realized in a period of time of one week, so,
% modifications to obtain the right data down per day have been done as
% well.
% =========================================================================
close all

% SIMULATION INPUT GOES HERE (AND IN STK)
altitudes=[400 600 800] ;      % different orbital altitudes
thresholds=0:90 ;              % different threshold elevation angles

% D and I is hold the average kB downloaded during an average day and an
% average pass , respectively , for various altitudes and thresholds .
W=zeros(length(altitudes),length(thresholds)) ;
D=W;
I=D;
R1=9600;                       %Assuming bit rate of 9600 bps  [bps]

% Read access information from fname.dat files. 
data4=read_stk_elev(fname_400) ;
data6=read_stk_elev(fname_600) ;
data8=read_stk_elev(fname_800) ;

for alt=1:length(altitudes)

  for thr=1:length(thresholds)

   % 400 %
    intervals=threshold_stk_elev(data4,thresholds(thr)) ;

    if (isempty(intervals)) % Elevation never passes threshold
      start4=0;
      stop4=0;
    else                    % Elevation is bigger than interval
      start4=datenum(intervals(:,1:6)) ;  
      stop4=datenum(intervals(:,7:12)) ;
    end

    duration_d4=stop4-start4; % This is the duration of the passes in days.
    duration_h4=duration_d4*24; % . . . and in hours
    duration_m4=duration_h4*60; % . . . and in minutes.
    duration_s4=duration_m4*60; % . . . and in seconds.
      
    T4=sum(duration_s4) ;      % Total duration of pass in seconds
         
    N4=size(intervals,1) ;     % The number of passes during the
                               % simulation time (1 week )
    W4=R1*T4; % Bits downloaded during simulation time (1 week) [bps]
    D4(alt,thr)=W4/7 ; % D is kB per average day. [bps]
    D4_m(alt,thr)=((W4/7)/1000)/1000 ; % D is bits per average day. [MBps]
    I4(alt,thr)=W4/N4; % I is kB download per average pass .
          
    % 600 %  
    intervals=threshold_stk_elev(data6,thresholds(thr)) ;
    if (isempty(intervals)) % Elevation never passes threshold
      start6=0;
      stop6=0;
    else                    % Elevation is bigger than interval
      start6=datenum(intervals(:,1:6)) ;  
      stop6=datenum(intervals(:,7:12)) ;
    end
    duration_d6=stop6-start6; % This is the duration of the passes in days.
    duration_h6=duration_d6*24; % . . . and in hours
    duration_m6=duration_h6*60; % . . . and in minutes.
    duration_s6=duration_m6*60; % . . . and in seconds.
    T6=sum(duration_s6) ;       % Total duration of pass in seconds
    N6=size(intervals,1) ;      % The number of passes during the
                                % simulation time (1 week )
    W6=R1*T6;          % Bits downloaded during simulation time (1 week)
    D6(alt,thr)=W6/7 ; % D is kB per average day [bps] 
    D6_m(alt,thr)=((W6/7)/1000)/1000 ; % D is bits per average day [MBits]
    I6(alt,thr)=W6/N6; % I is kB download per average pass .
        
    % 800 %
    intervals=threshold_stk_elev(data8,thresholds(thr)) ;

    if (isempty(intervals)) % Elevation never passes threshold
      start8=0;
      stop8=0;
    else                    % Elevation is bigger than interval
      start8=datenum(intervals(:,1:6)) ;  
      stop8=datenum(intervals(:,7:12)) ;
    end
    duration_d8=stop8-start8; % This is the duration of the passes in days.
    duration_h8=duration_d8*24; % . . . and in hours
    duration_m8=duration_h8*60; % . . . and in minutes.
    duration_s8=duration_m8*60; % . . . and in seconds.
    T8=sum(duration_s8) ;       % Total duration of pass in seconds
    N8=size(intervals,1) ;      % The number of passes during the
                                % simulation time (1 week)
    R8=9600; % Assuming bit rate of 9600 bps
    W8=R8*T8; % Bits downloaded during simulation time (1 week)
    D8(alt,thr)=W8/7 ; % D is bits per average day.[bps]
    D8_m(alt,thr)=((W8/7)/1000)/1000 ; % D is bits per average day. [MBps]
    I8(alt,thr)=W8/N8; % I is kB download per average pass .
    
  end
end

% Plot Data per Day in bits
figure
hold on
grid on
for alt=1:length(altitudes)
  plot(thresholds,D4(alt,:),'r') ;
  plot(thresholds,D6(alt,:),'g') ;
  plot(thresholds,D8(alt,:),'b') ;
end
xlabel ('Minimum Elevation Angle[degree]') ;
ylabel ('Average Downlink Capacity [bits/day]') ;
legend('400 km', '600 km','800 km') ;
title ('Average Data per Day' ) ;



% Plot Data per Day in Megabits
figure
hold on
grid on
for alt=1:length(altitudes)
  plot(thresholds,D4_m(alt,:),'r') ;
  plot(thresholds,D6_m(alt,:),'g') ;
  plot(thresholds,D8_m(alt,:),'b') ;
end
xlabel ('Minimum Elevation Angle[degree]') ;
ylabel ('Average Downlink Capacity [Mbits/day]') ;
legend('400 km', '600 km','800 km') ;
title ('Average Data per Day' ) ;

% Plot Data per Pass
figure
hold on
grid on
for alt=1:length(altitudes)
  plot(thresholds,I4(alt,:),'r') ;
  plot(thresholds,I6(alt,:),'g') ;
  plot(thresholds,I8(alt,:),'b') ;
end
xlabel ('Minimum Elevation Angle[degree]') ;
ylabel ('Average Downlink Capacity [bits/pass]') ;
legend('400 km', '600 km','800 km') ;
title ('Average Data per Pass' ) ;

