% This is a script that plots the downloaded data per average day for
% different orbital heights and threshold elevation angles.
% ==============================NOTES=====================================
% Modifications to read three files from STK simulations that corresponds
% to different heights, have been done. Present simulations was run in a
% period of time of 1 week, equations was adapted to it.
% ========================================================================

close all

% SIMULATION INPUT GOES HERE (AND IN STK)
altitudes=[400 600 800] ; % different orbital altitudes
thresholds=0:90 ; % different threshold elevation angles

% D and I is hold the average kB downloaded during an average day and an
% average pass , respectively , for various altitudes and thresholds .
W=zeros(length(altitudes),length(thresholds)) ;
D=W;
I=D;
T4=I; 
T6=I;
T8=I;

% Read access information from fname.dat files. 
data4=read_stk_elev(fname_400) ;
data6=read_stk_elev(fname_600) ;
data8=read_stk_elev(fname_800) ;

for alt=1:length(altitudes)

  for thr=1:length(thresholds)

   % 400 %     
      
    intervals=threshold_stk_elev(data4,thresholds(thr)) ;

    if (isempty(intervals)) % Elevation never passes threshold
      start4=0;
      stop4=0;
    else                    % Elevation is bigger than interval
      start4=datenum(intervals(:,1:6)) ;  
      stop4=datenum(intervals(:,7:12)) ;
    end

    duration_d4=stop4-start4;  % This is the duration of the passes in ...days .
    duration_h4=duration_d4*24; % . . . and in hours
    duration_m4=duration_h4*60; % . . . and in minutes.
    duration_s4=duration_m4*60; % . . . and in seconds.

    T4(alt,thr)=sum(duration_m4) ; % Total duration of pass in MIN
    T4(alt,thr)=(T4(alt,thr))/7 ;  % Total duration of pass in MIN PER DAY
    
    % 600 %     
      
    intervals=threshold_stk_elev(data6,thresholds(thr)) ;

    if (isempty(intervals)) % Elevation never passes threshold
      start6=0;
      stop6=0;
    else                    % Elevation is bigger than interval
      start6=datenum(intervals(:,1:6)) ;  
      stop6=datenum(intervals(:,7:12)) ;
    end

    duration_d6=stop6-start6; % This is the duration of the passes in ...days .
    duration_h6=duration_d6*24; % . . . and in hours
    duration_m6=duration_h6*60; % . . . and in minutes.
    duration_s6=duration_m6*60; % . . . and in seconds.
    
    T6(alt,thr)=sum(duration_m6) ; % Total duration of pass in MIN
    T6(alt,thr)=(T6(alt,thr))/7 ;  % Total duration of pass in MIN PER DAY
    
    % 600 %
           
    intervals=threshold_stk_elev(data8,thresholds(thr)) ;

    if (isempty(intervals)) % Elevation never passes threshold
      start8=0;
      stop8=0;
    else                    % Elevation is bigger than interval
      start8=datenum(intervals(:,1:6)) ;  
      stop8=datenum(intervals(:,7:12)) ;
    end

    duration_d8=stop8-start8; % This is the duration of the passes in ...days .
    duration_h8=duration_d8*24; % . . . and in hours
    duration_m8=duration_h8*60; % . . . and in minutes.
    duration_s8=duration_m8*60; % . . . and in seconds.
    
    T8(alt,thr)=sum(duration_m8) ; % Total duration of pass in MIN PER WEEK
    T8(alt,thr)=(T8(alt,thr))/7 ;  % Total duration of pass in MIN PER DAY
           
  end

end

% Plot Visibility time per Day
figure
hold on
grid on
for alt=1:length(altitudes)
  plot(thresholds,T4(alt,:),'r') ;
  plot(thresholds,T6(alt,:),'g') ;
  plot(thresholds,T8(alt,:),'b') ;
  
end
xlabel ('Minimum Elevation Angle[degree]') ;
ylabel ('Total duration per Day [minutes]') ;
legend('400 km', '600 km','800 km') ;
title ('Visibility Time' ) ;

